@@ -1,9 +1,10 @@
 from .api import get_arguments, get_params
 from .decorators import params
 from .enums import ParameterType
-from .errors import ResolutionError
+from .errors import ResolutionError, MissingSpecification
 from .manager import ParameterManager, ParamManager
 from .models import Arguments, BoundArguments, Parameter
 from .parameters import ParameterSpecification
 from .sentinels import Missing
 from .wrappers import Param
+from .resolvers import Resolvers, Resolver
